From ed909dba1d819f324f2cf77eb9862946b64474f2 Mon Sep 17 00:00:00 2001
From: tomas <93524600+TommiRommi@users.noreply.github.com>
Date: Fri, 27 Jan 2023 10:52:20 +0000
Subject: [PATCH] fixed spelling mistake

there was a spelling mistake in one of pointer warnings
---
 src/cc65/typeconv.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/cc65/typeconv.c b/src/cc65/typeconv.c
index 18a9f4dfa..683cb2356 100644
--- a/src/cc65/typeconv.c
+++ b/src/cc65/typeconv.c
@@ -238,10 +238,10 @@ void TypeConversion (ExprDesc* Expr, const Type* NewType)
             **       void pointers, just with warnings.
             */
             if (Result.C == TC_PTR_SIGN_DIFF) {
                 /* Specific warning for pointee signedness difference */
                 if (IS_Get (&WarnPointerSign)) {
                     TypeCompatibilityDiagnostic (NewType, Expr->Type,
-                        0, "Pointer conversion to '%s' from '%s' changes pointee signedness");
+                        0, "Pointer conversion to '%s' from '%s' changes pointer signess");
                 }
             } else if ((Result.C <= TC_PTR_INCOMPATIBLE ||
                  (Result.F & TCF_INCOMPATIBLE_QUAL) != 0)) {
@@ -238,10 +238,10 @@ void TypeConversion (ExprDesc* Expr, const Type* NewType)
             */
             if (Result.C == TC_PTR_SIGN_DIFF) {
-                /* Specific warning for pointee signedness difference */
+                /* Specific warning for pointer signess difference */
                 if (IS_Get (&WarnPointerSign)) {
                     TypeCompatibilityDiagnostic (NewType, Expr->Type,